pub struct SettingValueForm {
pub kind: SettingValueKind,
pub domain: Option<String>,
pub members: Vec<String>,
pub min: Option<f64>,
pub max: Option<f64>,
}Expand description
The value form a settings key accepts.
Fields
kind: SettingValueKindThe value shape.
domain: Option<String>The settings enum domain an enum key accepts members of.
members: Vec<String>The member spellings an enum slot accepts.
min: Option<f64>The numeric bounds the table declares, when it declares them.
max: Option<f64>The numeric upper bound, when declared.