pub fn parse_with_options(
tokens: &[Token],
allow_macro_redeclaration: bool,
) -> ParseOutputExpand description
Parse with the global redeclaration policy observed by the pinned oracle.
pub fn parse_with_options(
tokens: &[Token],
allow_macro_redeclaration: bool,
) -> ParseOutputParse with the global redeclaration policy observed by the pinned oracle.