pub fn preprocess(
main_text: &str,
main_path: &str,
root: &Path,
) -> OpyResult<(Preprocessed, Vec<FileRecord>)>Expand description
Preprocess the main source text with its include root.
pub fn preprocess(
main_text: &str,
main_path: &str,
root: &Path,
) -> OpyResult<(Preprocessed, Vec<FileRecord>)>Preprocess the main source text with its include root.