pub struct SettingsBlock {
pub text: String,
pub span: Span,
pub keyword_span: Span,
pub start: usize,
pub end: usize,
pub text_start: Position,
}Expand description
A top-of-file settings { ... } block.
Fields
text: StringThe raw JSONC text between the braces (braces excluded).
span: SpanThe whole block: the settings keyword through the closing brace.
keyword_span: SpanThe settings keyword token (diagnostic anchor).
start: usizeThe char offset of the settings keyword (for sanitization).
end: usizeThe char offset just past the closing brace (for sanitization).
text_start: PositionThe position of the first char of text (just past the opening brace).